#
# spec file for package python-param
#
# Copyright (c) 2018 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-param
Version:        1.6.0
Release:        lp151.2.2
Summary:        Declarative Python programming using Parameters
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://ioam.github.com/param/
Source:         https://files.pythonhosted.org/packages/source/p/param/param-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
Recommends:     python-numpy
BuildArch:      noarch
%python_subpackages

%description
Param is a library providing Parameters: Python attributes extended to
have features such as type and range checking, dynamically generated
values, documentation strings, default values, etc., each of which is
inherited from parent classes if not specified in a subclass.

Param contains only two required Python files, with no external
dependencies, and is provided freely for both non-commercial and
commercial use under a BSD license, so that it can easily be included
as part of other projects.

%prep
%setup -q -n param-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE.txt README.rst
%{python_sitelib}/param/
%{python_sitelib}/numbergen/
%{python_sitelib}/param-%{version}-py*.egg-info

%changelog
* Wed Apr 18 2018 toddrme2178@gmail.com
- Update to version 1.6.0
  * Drop Cython build
* Thu Aug 17 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 1.5.1
  * Fixed error messages for ClassSelector with tuple of classes
  * Added get and contains methods for ParamOverrides
- Update to version 1.5.0
  * Added Range, Color, and Date parameters
  * Improved ObjectSelector error messages
  * Minor bugfixes
* Tue Oct 25 2016 toddrme2178@gmail.com
- Update to version 1.4.2:
  * Improved version reporting from version module
  * Minor bugfixes
- update to version 1.4.1:
  * Changed Selector parameters to respect order of provided options
  * Allow softbounds to be accessed like an attribute
- update to version 1.4.0:
  * Improved import ordering in parameterized.py
  * Fixed problematic travis shield link
  * Added 1.3.2 release notes
  * Add pypy to .travis.yml
  * Updated badge definitions to point to working URLS
  * Added optional support for setuptools in setup.py
  * Removed out-of-date pyflakes ignore (imports are used).  69d00b5
  * Added flake8 to travis config (and for now, output does not affect...
  * flake8: ignore rule about white space after comma
  * Fixed the 'python versions' shield.
  * Enabled cythonizing of param modules if Cython is available
  * Removed testing of Python 3.2 from travis.yml
  * Added shared_parameters context manager
  * Added unit test for shared_parameters context manager
  * Skip processing non-parameterized classes in setup_param
  * Update index.rst
  * Fixed formatting in docs
  * Fixed date in docs
  * Fixed typo in docs
  * Cleaned up get_range 6942b4f
  * Fixed formatting of print_param_defaults under Python2.7 and
    Python3
  * Added new Parameter types from the paramnb project
  * Fixed previous commit for Python2.6 compatibility
  * Fixed tests for python2.6 compatibility
  * commit_count can now be set via the Version constructor
  * Updated docstring of param.Version constructor
* Fri Jul 10 2015 toddrme2178@gmail.com
- update to version 1.3.2:
  * Updated unit test of ParamPager in the param IPython extension
  * Suppressing default parameter object names from the ParamPager
    title
  * Made _get_param_info and _param_docstrings methods of Pager public
  * Unicode support for param.String
  * Added shield displaying all supported Python versions
  * Added check for default value of String
  * Minor fix to logging: python loggers can accept keyword arguments.
  * Fixed Pyflakes errors
  * Fixed trailing whitespaces
* Fri Apr 10 2015 toddrme2178@gmail.com
- update to version 1.3.1:
  * Minor bugfix release to restore pre-1.3.0 script_repr behavior
    (accidentally changed in 1.3.0) and to fix issues with logging.
  * Param’s logging interface now matches that of Python’s logging
    module, making it simpler to use logging (see Python’s logging
    module for details). Note therefore that Param’s logging methods
    (a) no longer call functions that are passed as arguments
    (instead, Python’s logging module does lazy string merges), and
    (b) no longer automatically combine strings passed as arguments
    (instead, Python’s logging module supports string formatting).
- update to version 1.3.0:
  * Added ‘allow_None’ support to all Parameters. Any subclass of
    Parameter that checks types and/or values should be modified to
    add appropriate handling of allow_None.
  * Improved pretty printing (script_repr) of Parameterized instances,
    and made available via the pprint method. The script_repr name
    will be removed in a future release.
  * Added (reproducible) time-dependent random streams
    (numbergen.TimeAwareRandomState).
  * Added label and unit parameters to param.Time class.
  * Improved optional IPython extension.
* Mon Jul 14 2014 toddrme2178@gmail.com
- Initial version
